@@ -49,7 +49,7 @@ extern "C" {
  * Inserts memory barriers on architectures that require them (currently only
  * Alpha) and documents which pointers are protected by RCU.
  *
- * The compiler memory barrier in LOAD_SHARED() ensures that value-speculative
+ * The compiler memory barrier in CMM_LOAD_SHARED() ensures that value-speculative
  * optimizations (e.g. VSS: Value Speculation Scheduling) does not perform the
  * data read before the pointer read by speculating the value of the pointer.
  * Correct ordering is ensured because the pointer is read as a volatile access.
@@ -62,8 +62,8 @@ extern "C" {
  */
 
 #define _rcu_dereference(p)     ({					\
-				typeof(p) _________p1 = LOAD_SHARED(p); \
-				smp_read_barrier_depends();		\
+				typeof(p) _________p1 = CMM_LOAD_SHARED(p); \
+				cmm_smp_read_barrier_depends();		\
 				(_________p1);				\
 				})
 
@@ -81,7 +81,7 @@ extern "C" {
 		typeof(*p) _________pnew = (_new);			\
 		if (!__builtin_constant_p(_new) ||			\
 		    ((_new) != NULL))					\
-			wmb();						\
+			cmm_wmb();						\
 		uatomic_cmpxchg(p, _________pold, _________pnew);	\
 	})
 
@@ -96,7 +96,7 @@ extern "C" {
 		typeof(*p) _________pv = (v);		\
 		if (!__builtin_constant_p(v) ||		\
 		    ((v) != NULL))			\
-			wmb();				\
+			cmm_wmb();				\
 		uatomic_xchg(p, _________pv);		\
 	})
 
@@ -106,7 +106,7 @@ extern "C" {
 		typeof(*p) _________pv = (v);		\
 		if (!__builtin_constant_p(v) || 	\
 		    ((v) != NULL))			\
-			wmb();				\
+			cmm_wmb();				\
 		uatomic_set(p, _________pv);		\
 	})
 
