@@ -10,7 +10,7 @@
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
-*
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
@@ -28,13 +28,13 @@
 extern "C" {
 #endif
 
-#define mb()			asm volatile("mb":::"memory")
-#define wmb()			asm volatile("wmb":::"memory")
-#define read_barrier_depends()	asm volatile("mb":::"memory")
+#define cmm_mb()			asm volatile("mb":::"memory")
+#define cmm_wmb()			asm volatile("wmb":::"memory")
+#define cmm_read_barrier_depends()	asm volatile("mb":::"memory")
 
 typedef unsigned long long cycles_t;
 
-static inline cycles_t get_cycles (void)
+static inline cycles_t caa_get_cycles (void)
 {
 	return 0;	/* not supported */
 }
