@@ -26,26 +26,26 @@
 
 
 /* Basic type for the double-link list.  */
-typedef struct list_head
+typedef struct cds_list_head
 {
-  struct list_head *next;
-  struct list_head *prev;
+  struct cds_list_head *next;
+  struct cds_list_head *prev;
 } list_t;
 
 
 /* Define a variable with the head and tail of the list.  */
-#define LIST_HEAD(name) \
+#define CDS_LIST_HEAD(name) \
   list_t name = { &(name), &(name) }
 
 /* Initialize a new list head.  */
-#define INIT_LIST_HEAD(ptr) \
+#define CDS_INIT_LIST_HEAD(ptr) \
   (ptr)->next = (ptr)->prev = (ptr)
 
-#define LIST_HEAD_INIT(name) { .prev = &(name), .next = &(name) }
+#define CDS_LIST_HEAD_INIT(name) { .prev = &(name), .next = &(name) }
 
 /* Add new element at the head of the list.  */
 static inline void
-list_add (list_t *newp, list_t *head)
+cds_list_add (list_t *newp, list_t *head)
 {
   head->next->prev = newp;
   newp->next = head->next;
@@ -56,7 +56,7 @@ list_add (list_t *newp, list_t *head)
 
 /* Add new element at the tail of the list.  */
 static inline void
-list_add_tail (list_t *newp, list_t *head)
+cds_list_add_tail (list_t *newp, list_t *head)
 {
   head->prev->next = newp;
   newp->next = head;
@@ -67,7 +67,7 @@ list_add_tail (list_t *newp, list_t *head)
 
 /* Remove element from list.  */
 static inline void
-__list_del (list_t *prev, list_t *next)
+__cds_list_del (list_t *prev, list_t *next)
 {
   next->prev = prev;
   prev->next = next;
@@ -75,23 +75,23 @@ __list_del (list_t *prev, list_t *next)
 
 /* Remove element from list.  */
 static inline void
-list_del (list_t *elem)
+cds_list_del (list_t *elem)
 {
-  __list_del (elem->prev, elem->next);
+  __cds_list_del (elem->prev, elem->next);
 }
 
 /* delete from list, add to another list as head */
 static inline void
-list_move (list_t *elem, list_t *head)
+cds_list_move (list_t *elem, list_t *head)
 {
-  __list_del (elem->prev, elem->next);
-  list_add (elem, head);
+  __cds_list_del (elem->prev, elem->next);
+  cds_list_add (elem, head);
 }
 
 /* replace an old entry.
  */
 static inline void
-list_replace(list_t *old, list_t *_new)
+cds_list_replace(list_t *old, list_t *_new)
 {
 	_new->next = old->next;
 	_new->prev = old->prev;
@@ -101,7 +101,7 @@ list_replace(list_t *old, list_t *_new)
 
 /* Join two lists.  */
 static inline void
-list_splice (list_t *add, list_t *head)
+cds_list_splice (list_t *add, list_t *head)
 {
   /* Do nothing if the list which gets added is empty.  */
   if (add != add->next)
@@ -115,56 +115,56 @@ list_splice (list_t *add, list_t *head)
 
 
 /* Get typed element from list at a given position.  */
-#define list_entry(ptr, type, member) \
+#define cds_list_entry(ptr, type, member) \
   ((type *) ((char *) (ptr) - (unsigned long) (&((type *) 0)->member)))
 
 
 
 /* Iterate forward over the elements of the list.  */
-#define list_for_each(pos, head) \
+#define cds_list_for_each(pos, head) \
   for (pos = (head)->next; pos != (head); pos = pos->next)
 
 
 /* Iterate forward over the elements of the list.  */
-#define list_for_each_prev(pos, head) \
+#define cds_list_for_each_prev(pos, head) \
   for (pos = (head)->prev; pos != (head); pos = pos->prev)
 
 
 /* Iterate backwards over the elements list.  The list elements can be
    removed from the list while doing this.  */
-#define list_for_each_prev_safe(pos, p, head) \
+#define cds_list_for_each_prev_safe(pos, p, head) \
   for (pos = (head)->prev, p = pos->prev; \
        pos != (head); \
        pos = p, p = pos->prev)
 
-#define list_for_each_entry(pos, head, member)				\
-	for (pos = list_entry((head)->next, typeof(*pos), member);	\
+#define cds_list_for_each_entry(pos, head, member)				\
+	for (pos = cds_list_entry((head)->next, typeof(*pos), member);	\
 	     &pos->member != (head);					\
-	     pos = list_entry(pos->member.next, typeof(*pos), member))
+	     pos = cds_list_entry(pos->member.next, typeof(*pos), member))
 
-#define list_for_each_entry_reverse(pos, head, member)			\
-	for (pos = list_entry((head)->prev, typeof(*pos), member);	\
+#define cds_list_for_each_entry_reverse(pos, head, member)			\
+	for (pos = cds_list_entry((head)->prev, typeof(*pos), member);	\
 	     &pos->member != (head);					\
-	     pos = list_entry(pos->member.prev, typeof(*pos), member))
+	     pos = cds_list_entry(pos->member.prev, typeof(*pos), member))
 
-#define list_for_each_entry_safe(pos, p, head, member)			\
-	for (pos = list_entry((head)->next, typeof(*pos), member),	\
-		     p = list_entry(pos->member.next,typeof(*pos), member); \
+#define cds_list_for_each_entry_safe(pos, p, head, member)			\
+	for (pos = cds_list_entry((head)->next, typeof(*pos), member),	\
+		     p = cds_list_entry(pos->member.next,typeof(*pos), member); \
 	     &pos->member != (head);					\
-	     pos = p, p = list_entry(pos->member.next, typeof(*pos), member))
+	     pos = p, p = cds_list_entry(pos->member.next, typeof(*pos), member))
 
-static inline int list_empty(list_t *head)
+static inline int cds_list_empty(list_t *head)
 {
 	return head == head->next;
 }
 
-static inline void list_replace_init(list_t *old,
+static inline void cds_list_replace_init(list_t *old,
 				     list_t *_new)
 {
 	list_t *head = old->next;
-	list_del(old);
-	list_add_tail(_new, head);
-	INIT_LIST_HEAD(old);
+	cds_list_del(old);
+	cds_list_add_tail(_new, head);
+	CDS_INIT_LIST_HEAD(old);
 }
 
 #endif	/* list.h */
